use cfg_if::cfg_if;

cfg_if! { if #[cfg(feature = "ssr")] {
    use sqlx::{Postgres, Transaction};
    use sqlx::{query_as, query};
    use sqlx::Error;
    use crate::backend::data::Customer;
    use std::ops::DerefMut;

    pub async fn find_customer_by_email(email: &str, tx: &mut Transaction<'_, Postgres>) -> Option<Customer> {
        let customer = query_as::<_, Customer>("SELECT * FROM customer WHERE email = $1")
            .bind(email)
            .fetch_one(tx.deref_mut())
            .await.unwrap_or_default();

        if customer.email == email {
            Some(customer)
        } else {
            None
        }
    }

    pub async fn sync_customer_data(customer: &Customer, full_name: &str, phone: &str, tx: &mut Transaction<'_, Postgres>) -> Result<Customer, Error> {
        if &customer.full_name != full_name || &customer.phone != phone {
            query("UPDATE CUSTOMER SET full_name=$1, phone=$2 WHERE id=$3")
                .bind(full_name)
                .bind(phone)
                .bind(customer.id())
                .execute(tx.deref_mut())
                .await?;
            Ok(Customer::new(customer.id(),
                full_name.to_string(),
                customer.email.clone(),
                phone.to_string(),
                customer.discount))
        } else {
            Ok(customer.clone())
        }
    }

    pub async fn create_customer(full_name: &str, email: &str, phone: &str, tx: &mut Transaction<'_, Postgres>) -> Result<Customer, Error> {
        query("INSERT INTO customer(full_name, email, phone) VALUES($1, $2, $3)")
            .bind(full_name)
            .bind(email)
            .bind(phone)
            .execute(tx.deref_mut())
            .await?;
        Ok(find_customer_by_email(email, tx).await.ok_or(Error::RowNotFound)?)
    }
}}
