use chrono::{NaiveDate, Weekday};
use leptos::use_context;
use crate::locales::catalogues::get_dictionary;

mod catalogues;

#[derive(Debug, Clone)]
pub struct Locales(pub Vec<Option<String>>);

pub fn init_locales() {
    #[cfg(not(feature = "ssr"))]
    {
        use leptos::*;
        let loc = Locales(
            window()
                .navigator()
                .languages()
                .into_iter()
                .map(|val| val.as_string())
                .collect::<Vec<_>>(),
        );
        provide_context(loc);
    }
}

pub fn trl(phrase: &str) -> impl Fn() -> String {
    let mut translated = phrase;
    if let Some(dict) = get_dictionary() {
        if let Some(p) = dict.get(phrase.to_string().as_str()) {
            translated = *p;
        }
    }

    let out = translated.to_string();

    move || { out.clone() }
}

// ToDo better date formatting
pub fn loc_date(date: NaiveDate) -> impl Fn() -> String {
    let mut dt = date.format("%Y-%m-%d").to_string();
    let locs = use_context::<Locales>().unwrap_or(Locales(vec![])).0;
    for loc in locs {
        if let Some(key) = loc {
            if let Some(k) = key.split("-").collect::<Vec<_>>().get(0) {
                if *k != "en" {
                    dt = date.format("%d. %m. %Y").to_string();
                }
            }
        }
    }

    move || { dt.clone() }
}

pub fn show_day(day: &Weekday) -> impl Fn() -> String {
    match day {
        Weekday::Mon => { trl("Monday") }
        Weekday::Tue => { trl("Tuesday") }
        Weekday::Wed => { trl("Wednesday") }
        Weekday::Thu => { trl("Thursday") }
        Weekday::Fri => { trl("Friday") }
        Weekday::Sat => { trl("Saturday") }
        Weekday::Sun => { trl("Sunday") }
    }
}